@@ -119,7 +119,7 @@ module Prawn
 
           if skip
             # the call has been overridden
-          elsif children.empty?
+          elsif children.empty? && call != 'transparent' # some prawn calls complain if they aren't supplied a block
             prawn.send(call, *arguments)
           else
             prawn.send(call, *arguments, &proc_creator(prawn, children))
@@ -172,6 +172,15 @@ module Prawn
             @cursor = [at[0] + width, at[1]]
           end
 
+          decoration = options.delete(:decoration)
+          if decoration == 'underline'
+            prawn.save_graphics_state do
+              prawn.line_width 1
+              prawn.line [at[0], at[1] - 1.25], [at[0] + width, at[1] - 1.25]
+              prawn.stroke
+            end
+          end
+
         when 'transformation_matrix'
           left = prawn.bounds.absolute_left
           top = prawn.bounds.absolute_top
